import { ImpactHapticFeedbackStyle, NotificationHapticFeedbackType, Bridge } from '../Bridge';
import { WebApp } from '../WebApp';
/**
 * Class which controls haptic feedback. It allows calling different types of
 * haptic notifications.
 */
export declare class HapticFeedback {
    private bridge;
    private webApp;
    constructor(bridge: Bridge, webApp: WebApp);
    /**
     * A method tells that an impact occurred. The Telegram app may play the
     * appropriate haptics based on style value passed.
     *
     * @param style - impact style.
     * @since Web App version 6.1+
     */
    impactOccurred: (style: ImpactHapticFeedbackStyle) => void;
    /**
     * A method tells that a task or action has succeeded, failed, or produced
     * a warning. The Telegram app may play the appropriate haptics based on
     * type value passed.
     *
     * @param type - notification type.
     * @since Web App version 6.1+
     */
    notificationOccurred: (type: NotificationHapticFeedbackType) => void;
    /**
     * A method tells that the user has changed a selection. The Telegram app
     * may play the appropriate haptics.
     *
     * Do not use this feedback when the user makes or confirms a selection;
     * use it only when the selection changes.
     *
     * @since Web App version 6.1+
     */
    selectionChanged: () => void;
}
